==> mysql-proxy_0.8.0.orig.tar.gz: mysql-proxy-0.8.0/tests/suite/base/t/lineno.lua <==
--[[ $%BEGINLICENSE%$
 Copyright (C) 2007 MySQL AB, 

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; version 2 of the License.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA

 $%ENDLICENSE%$ --]]

local proto = assert(require("mysql.proto"))

function connect_server()
	-- emulate a server
	proxy.response = {
		type = proxy.MYSQLD_PACKET_RAW,
		packets = {
			proto.to_challenge_packet({})
		}
	}
	return proxy.PROXY_SEND_RESULT
end

function read_query(packet)
	if packet:byte() ~= proxy.COM_QUERY then
		proxy.response = {
			type = proxy.MYSQLD_PACKET_OK,
		}
		return proxy.PROXY_SEND_RESULT
	end

	if packet:sub(2) == "SELECT backtrace" then
		proxy.response = {
			type = proxy.MYSQLD_PACKET_OK,
			resultset = {
				fields = {
					{ name = "backtrace", type = proxy.MYSQL_TYPE_STRING }
				},
				rows = { 
					{ debug.traceback() }
				}

			}
		}
	else
		proxy.response = {
			type = proxy.MYSQLD_PACKET_ERR,
			errmsg = packet:sub(2)
		}
	end
	return proxy.PROXY_SEND_RESULT
end

==> mysql-proxy_0.8.1.orig.tar.gz: mysql-proxy-0.8.1/tests/suite/base/t/lineno.lua <==
--[[ NEVER change the number of lines of this license header without also changing r/lineno.result. Thus we don't dynamically update the license header, either.
 Copyright (c) 2009, Oracle and/or its affiliates. All rights reserved.

 This program is free software; you can redistribute it and/or modify
 it under the terms of the GNU General Public License as published by
 the Free Software Foundation; version 2 of the License.

 This program is distributed in the hope that it will be useful,
 but WITHOUT ANY WARRANTY; without even the implied warranty of
 MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 GNU General Public License for more details.

 You should have received a copy of the GNU General Public License
 along with this program; if not, write to the Free Software
 Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301  USA

 --]]

local proto = assert(require("mysql.proto"))

function connect_server()
	-- emulate a server
	proxy.response = {
		type = proxy.MYSQLD_PACKET_RAW,
		packets = {
			proto.to_challenge_packet({})
		}
	}
	return proxy.PROXY_SEND_RESULT
end

function read_query(packet)
	if packet:byte() ~= proxy.COM_QUERY then
		proxy.response = {
			type = proxy.MYSQLD_PACKET_OK,
		}
		return proxy.PROXY_SEND_RESULT
	end

	if packet:sub(2) == "SELECT backtrace" then
		proxy.response = {
			type = proxy.MYSQLD_PACKET_OK,
			resultset = {
				fields = {
					{ name = "backtrace", type = proxy.MYSQL_TYPE_STRING }
				},
				rows = { 
					{ debug.traceback() }
				}

			}
		}
	else
		proxy.response = {
			type = proxy.MYSQLD_PACKET_ERR,
			errmsg = packet:sub(2)
		}
	end
	return proxy.PROXY_SEND_RESULT
end
